---
title: Home
hide:
  - navigation
  - toc
---

<center>
# Digital Forensics Investigative Questions
<img src="assets/dfiq-blue.png" alt="DFIQ Logo" width=600>
</center>

DFIQ is a collection of Digital Forensics Investigative Questions and the approaches to answering them.
The goal of the project is to build a comprehensive catalog of investigative knowledge to help drive 
consistent, thorough, and explainable investigations.

## Key Aspects of DFIQ:

* DFIQ is a catalog of investigative knowledge, centered on [Questions](/questions)
* Uses the concept of [Scenarios](/scenarios) to logically group Questions and help structure investigations
* Stores data in an easily-readable, tool-agnostic format (YAML) to be used by others

<center>
## Get Started!

[View Questions](/questions){ .md-button } &nbsp; [View Scenarios](/scenarios){ .md-button }
</center>